HawkesProcess

Struct HawkesProcess 

pub struct HawkesProcess<K: Kernel> {
    pub mu: f64,
    pub kernel: K,
    /* private fields */
}
Hawkes process with arbitrary kernel.

Simulated via Ogata’s thinning algorithm. For exponential kernels, intensity is maintained O(1) via the recursion I(t+dt) = mu + (I(t) - mu) * exp(-beta*dt) + alpha * new_jumps. For non-exponential kernels, intensity is computed by summing over all historical jumps (O(n)).

Fields

mu: f64kernel: K

Implementations

Source

impl<K: Kernel> HawkesProcess<K>

pub fn new(mu: f64, kernel: K) -> Self

pub fn value(&self) -> f64

Source

impl<K: Kernel + 'static> HawkesProcess<K>

Simulate the Hawkes process and return the intensity path on a grid.

pub fn simulate_intensity(&self, total_time: f64, n_steps: usize) -> Vec<f64>